Description: ErMagicBuilder help window
Keywords: ErMagicBuilderHelp

### Earth-Ref Magic Specimen Help Window

- Update the relationship between specimens and samples. You may not rename specimens, but you may reassign them to a different sample.
- It is also possible to add additional samples, using the "Add new sample" button.
- Note that specimen_type, specimen_lithology, and specimen_class columns do not show up. They will propagate down when you select sample_type, sample_lithology, and sample_class in step 4.